@@ -3,7 +3,7 @@ BEGIN {
   $Benchmark::Perl::Formance::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Perl 5 performance benchmarking framework
-$Benchmark::Perl::Formance::VERSION = '0.44';
+$Benchmark::Perl::Formance::VERSION = '0.45';
 use 5.008;
 
 use warnings;
@@ -636,31 +636,6 @@ sub run {
         do { usage;                exit  0 } if $help;
         do { usage;                exit -1 } if not $ok;
 
-        # Verify result storage before we start to avoid wasting benchmark time
-        if ($self->{options}{benchmarkanything_report})
-        {
-                print STDERR "# Wait for result store..." if $self->{options}{verbose} >= 2;
-                my $retry_sleep = 1;
-
-        RETRY:
-                eval {
-                        require BenchmarkAnything::Storage::Frontend::Lib;
-                        my $just_for_checking_balib = BenchmarkAnything::Storage::Frontend::Lib->new(verbose => $self->{options}{verbose});
-
-                        # dies if not available
-                        $just_for_checking_balib->connect;
-                        $just_for_checking_balib->disconnect;
-                        undef($just_for_checking_balib);
-                };
-                if ($@) {
-                        print STDERR "." if $self->{options}{verbose};
-                        sleep $retry_sleep;
-                        $retry_sleep *= 2 unless $retry_sleep > 3600; # exponential back-off until ~1h
-                        goto RETRY;
-                }
-                print STDERR "\n" if $self->{options}{verbose} >= 2;
-        }
-
         # use forks if requested
         if ($useforks) {
                 eval "use forks"; ## no critic
@@ -824,11 +799,12 @@ sub print_results
         }
         elsif ($self->{options}{benchmarkanything_report})
         {
-                require BenchmarkAnything::Storage::Frontend::Lib;
-                my $balib = BenchmarkAnything::Storage::Frontend::Lib->new(verbose => $self->{options}{verbose});
+                my $ba_reporter;
+                $ba_reporter = BenchmarkAnything::Reporter->new(verbose => $self->{options}{verbose});
 
                 eval {
-                        $balib->add({BenchmarkAnythingData => $RESULTS->{BenchmarkAnythingData}});
+                        require BenchmarkAnything::Reporter;
+                        $ba_reporter->report({BenchmarkAnythingData => $RESULTS->{BenchmarkAnythingData}});
                 };
                 if ($@)
                 {
@@ -841,10 +817,19 @@ sub print_results
 
                         my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime();
 
-                        my $home_ba            = File::Basename::dirname($balib->{cfgfile});
+                        my $result_dir = File::Basename::dirname($ba_reporter->{config}{cfgfile});
+                        if (! -w $result_dir) {
+                                require File::HomeDir;
+                                $result_dir = File::HomeDir->my_home;
+                        }
+                        if (! -w $result_dir) {
+                                require File::Temp;
+                                $result_dir = tempdir(CLEANUP => 0);
+                        }
+
                         my $timestamp1         = sprintf("%04d-%02d-%02d", 1900+$year, $mon, $mday);
                         my $timestamp2         = sprintf("%02d-%02d-%02d", $hour, $min, $sec);
-                        my $result_path        = "$home_ba/unreported_results/$timestamp1";
+                        my $result_path        = "$result_dir/unreported_results/$timestamp1";
 
                         File::Path::make_path($result_path);
 
@@ -878,10 +863,6 @@ values that you can compare against other runs of this suite,
 e.g. with other versions of Perl, modified compile parameter, or
 another set of dependent libraries.
 
-=head1 AUTHOR
-
-Steffen Schwigon, C<< <ss5 at renormalist.net> >>
-
 =head1 BUGS
 
 =head2 No invariant dependencies
@@ -914,51 +895,6 @@ knowledge about "real" benchmark science.
 Anyway, feel free to implement "real" benchmark ideas and send me
 patches.
 
-=head2 Bug reports
-
-Please report any bugs or feature requests to C<bug-perl-formance at
-rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Perl-Formance>.  I
-will be notified, and then you will automatically be notified of
-progress on your bug as I make changes.
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Benchmark::Perl::Formance
-
-You can also look for information at:
-
-=over 4
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Perl-Formance>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Perl-Formance>
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Perl-Formance>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Perl-Formance>
-
-=back
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2008-2010 Steffen Schwigon.
-
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
 =head1 AUTHOR
 
 Steffen Schwigon <ss5@renormalist.net>
